PersistentFooterConfig class

Constructors

PersistentFooterConfig({List<Widget>? buttons, AlignmentDirectional alignment = AlignmentDirectional.centerEnd})
const

Properties

alignment AlignmentDirectional
final
buttons List<Widget>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited