SButtonSelectableConfig class

Configuration for the selectable / toggle state of SButton.selectable.

This is a pure Dart domain entity with no Flutter/presentation layer dependencies. It holds all the customization knobs for the selected state.

Constructors

SButtonSelectableConfig({SColorValue? selectedBackgroundColor, SColorValue? selectedForegroundColor, SColorValue? selectedBorderColor, double selectedBorderWidth = 1.5, bool showCheckIcon = false, SSelectableCheckAlignment checkAlignment = SSelectableCheckAlignment.leading, Duration animationDuration = const Duration(milliseconds: 200), SSelectableCurve animationCurve = SSelectableCurve.easeInOut})
const

Properties

animationCurve SSelectableCurve
final
animationDuration Duration
final
checkAlignment SSelectableCheckAlignment
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBackgroundColor SColorValue?
final
selectedBorderColor SColorValue?
final
selectedBorderWidth double
final
selectedForegroundColor SColorValue?
final
showCheckIcon bool
final

Methods

copyWith({SColorValue? selectedBackgroundColor, SColorValue? selectedForegroundColor, SColorValue? selectedBorderColor, double? selectedBorderWidth, bool? showCheckIcon, SSelectableCheckAlignment? checkAlignment, Duration? animationDuration, SSelectableCurve? animationCurve}) SButtonSelectableConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited