SSelectThemeData class

Theme data for SSelect.

Inheritance

Constructors

SSelectThemeData({required Color backgroundColor, required Color itemColor, required Color selectedItemColor, required Color selectedItemBackgroundColor, required Color disabledColor, required Color iconColor, required Color borderColor})
Creates an instance of SSelectThemeData.
const

Properties

backgroundColor Color
Background color of the select dropdown.
final
borderColor Color
Border color of the select field.
final
disabledColor Color
Color when select is disabled.
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color
Icon color for the dropdown arrow.
final
itemColor Color
Text color for unselected items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItemBackgroundColor Color
Background color for selected items.
final
selectedItemColor Color
Text color for selected items.
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColor, Color? itemColor, Color? selectedItemColor, Color? selectedItemBackgroundColor, Color? disabledColor, Color? iconColor, Color? borderColor}) SSelectThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<SSelectThemeData>? other, double t) SSelectThemeData
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited