STooltipThemeData class

Theme data for STooltip.

Inheritance
Annotations

Constructors

STooltipThemeData({required Color backgroundColor, required Color textColor, EdgeInsetsGeometry? padding, BorderRadiusGeometry? borderRadius, bool showArrow = true, double arrowSize = 5.0, double elevation = 0.0, Duration animationDuration = const Duration(milliseconds: 200), TextStyle? textStyle, Color? shadowColor})
const

Properties

animationDuration Duration
The duration of the fade/scale animation.
final
arrowSize double
The size (height/base) of the triangle arrow.
final
backgroundColor Color
The background color of the tooltip bubble.
final
borderRadius BorderRadiusGeometry?
The border radius of the tooltip bubble.
final
elevation double
The elevation of the tooltip (box shadow).
final
hashCode int
The hash code for this object.
no setteroverride
padding EdgeInsetsGeometry?
The padding inside the tooltip bubble.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
The shadow color.
final
showArrow bool
Whether to show the orientation arrow.
final
textColor Color
The color of the text inside the tooltip.
final
textStyle TextStyle?
The text style for the tooltip label.
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? backgroundColor, Color? textColor, EdgeInsetsGeometry? padding, BorderRadiusGeometry? borderRadius, bool? showArrow, double? arrowSize, double? elevation, Duration? animationDuration, TextStyle? textStyle, Color? shadowColor}) STooltipThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<STooltipThemeData>? other, double t) STooltipThemeData
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override