SSonnerThemeData class
Theme data for SSonner.
- Inheritance
-
- Object
- ThemeExtension<
SSonnerThemeData> - SSonnerThemeData
- Annotations
Constructors
- SSonnerThemeData({required Color backgroundColor, required Color textColor, required Color successColor, required Color errorColor, required Color infoColor, required Color warningColor, required Color iconColor, required BorderRadiusGeometry borderRadius, required double elevation, Color? shadowColor, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? closeIconColor, TextStyle? titleStyle, TextStyle? descriptionStyle, ButtonStyle? actionButtonStyle})
-
Creates an instance of SSonnerThemeData.
const
Properties
- actionButtonStyle → ButtonStyle?
-
Style for the action button.
final
- backgroundColor → Color
-
Background color of the sonner notification.
final
- borderRadius → BorderRadiusGeometry
-
Border radius of the notification card.
final
- closeIconColor → Color?
-
Color of the close icon.
final
- descriptionStyle → TextStyle?
-
Style for the description text.
final
- elevation → double
-
Elevation of the notification card.
final
- errorColor → Color
-
Color for error notifications.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iconColor → Color
-
Icon color for notifications.
final
- infoColor → Color
-
Color for info notifications.
final
- margin → EdgeInsetsGeometry?
-
Margin around the notification card.
final
- padding → EdgeInsetsGeometry?
-
Padding inside the notification card.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → Color?
-
Shadow color of the notification card.
final
- successColor → Color
-
Color for success notifications.
final
- textColor → Color
-
Text color of the sonner notification.
final
- titleStyle → TextStyle?
-
Style for the title text.
final
- type → Object
-
The extension's type.
no setterinherited
- warningColor → Color
-
Color for warning notifications.
final
Methods
-
copyWith(
{Color? backgroundColor, Color? textColor, Color? successColor, Color? errorColor, Color? infoColor, Color? warningColor, Color? iconColor, BorderRadiusGeometry? borderRadius, double? elevation, Color? shadowColor, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? closeIconColor, TextStyle? titleStyle, TextStyle? descriptionStyle, ButtonStyle? actionButtonStyle}) → SSonnerThemeData -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< SSonnerThemeData> ? other, double t) → SSonnerThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override